.. _tutorials:

=========
Tutorials
=========

.. Note::
    We are transition the tutorials from sphinx-gallery to jupyter notebooks. Some links might be broken and we are working on fixing them.

.. toctree::
   :maxdepth: 1

   tutorials/kim_SW_Si
   tutorials/nn_Si
   tutorials/nn_SiC
   tutorials/parameter_transform
   tutorials/uq_mcmc
   tutorials/uq_bootstrap
   tutorials/lennard_jones
   tutorials/linear_regression
